<?php
// Post Meta Box

/**
 * Add meta box
 *
 * @param post $post The post object
 * @link https://codex.wordpress.org/Plugin_API/Action_Reference/add_meta_boxes
 */

function twinkle_post_settings_custom_meta_boxes( $post ) {
    add_meta_box( 
        'twinkle-post-settings',
        __( 'Post Settings', 'twinkle' ),
        'twinkle_post_settings_meta_box',
        'post',
        'normal',
        'high'
    );
}
add_action( 'add_meta_boxes_post', 'twinkle_post_settings_custom_meta_boxes' );
/**
 * Build custom field meta box
 *
 * @param post $post The post object
 */
function twinkle_post_settings_meta_box( $post ){

  // make sure the form request comes from WordPress
  wp_nonce_field( basename( __FILE__ ), 'twinkle_meta_box_nonce' );

  $twinkle_feature_post           = ( '' !== ( get_post_meta( $post->ID, 'twinkle_feature_post', true ) ) )            ? get_post_meta( $post->ID, 'twinkle_feature_post', true )        : '0';
  $twinkle_current_post_style     = ( '' !== ( get_post_meta( $post->ID, 'twinkle_post_style', true ) ) )              ? get_post_meta( $post->ID, 'twinkle_post_style', true )          : 'Style 1';
  $twinkle_current_featured_video = ( NULL !== ( get_post_meta( $post->ID, 'twinkle_featured_video', true ) ) )        ? get_post_meta( $post->ID, 'twinkle_featured_video', true )      : '';
  $twinkle_current_image_as_cover = ( '' !== ( get_post_meta( $post->ID, 'twinkle_image_as_videocover', true ) ) )     ? get_post_meta( $post->ID, 'twinkle_image_as_videocover', true ) : '0';

  ?>

  <div class='inside'>

    <h3 style="border-bottom: 1px solid #dedede;padding-bottom: 10px;margin-top: 30px;"><?php esc_html_e( 'Show Post in Featured Slider?', 'twinkle' ); ?></h3>
    <p>
      <input type="radio" name="twinkle_feature_post" value="0" <?php checked( $twinkle_feature_post, '0' ); ?> /><?php esc_html_e('No', 'twinkle'); ?><br />
      <input type="radio" name="twinkle_feature_post" value="1" <?php checked( $twinkle_feature_post, '1' ); ?> /><?php esc_html_e('Yes', 'twinkle'); ?>
    </p>
    <h3 style="border-bottom: 1px solid #dedede;padding-bottom: 10px;margin-top: 30px;"><?php esc_html_e( 'Post Style', 'twinkle' ); ?></h3>
    <p>
      <input type="radio" name="twinkle_current_post_style" value="Style 1" <?php checked( $twinkle_current_post_style, 'Style 1' ); ?> /><?php esc_html_e('Style 1', 'twinkle'); ?><br />
      <input type="radio" name="twinkle_current_post_style" value="Style 2" <?php checked( $twinkle_current_post_style, 'Style 2' ); ?> /><?php esc_html_e('Style 2', 'twinkle'); ?><br />
      <input type="radio" name="twinkle_current_post_style" value="Style 3" <?php checked( $twinkle_current_post_style, 'Style 3' ); ?> /><?php esc_html_e('Style 3', 'twinkle'); ?><br />
    </p>
    <h3 style="border-bottom: 1px solid #dedede;padding-bottom: 10px;margin-top: 30px;"><?php esc_html_e( 'Featured Video?', 'twinkle' ); ?></h3>
    <p><?php esc_html_e( 'If you want to use a Video enter the url (Youtube / Vimeo) in the field below', 'twinkle' ); ?></p>
    <p>
      <label><?php esc_html_e('Video URL:', 'twinkle'); ?></label>
      <input type="text" name="twinkle_featuredvideo" size="50" value="<?php echo esc_url($twinkle_current_featured_video); ?>" /> 
    </p> 
    <h3 style="border-bottom: 1px solid #dedede;padding-bottom: 10px;margin-top: 30px;"><?php esc_html_e( 'Use Featured Image as Video Cover?', 'twinkle' ); ?></h3>
    <p>
      <input type="radio" name="twinkle_imagecover" value="0" <?php checked( $twinkle_current_image_as_cover, '0' ); ?> /><?php esc_html_e('No', 'twinkle'); ?><br />
      <input type="radio" name="twinkle_imagecover" value="1" <?php checked( $twinkle_current_image_as_cover, '1' ); ?> /><?php esc_html_e('Yes', 'twinkle'); ?>
    </p>
    
  </div>
  <?php
}

/**
 * Store custom field meta box data
 *
 * @param int $post_id The post ID.
 * @link https://codex.wordpress.org/Plugin_API/Action_Reference/save_post
 */
function twinkle_save_meta_box_data( $post_id ){
    // verify taxonomies meta box nonce
    if ( isset($_POST['twinkle_meta_box_nonce'])){
      $twinkle_meta_box_nonce = sanitize_text_field( wp_unslash($_POST['twinkle_meta_box_nonce']));
    }
    

    if ( !isset( $twinkle_meta_box_nonce ) || !wp_verify_nonce( $twinkle_meta_box_nonce, basename( __FILE__ ) ) ){
      return;
    }

    // return if autosave
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){
      return;
    }

    // Check user permissions
    if ( ! current_user_can( 'edit_post', $post_id ) ){
      return;
    }

    $post_type = get_post_type( $post_id );
    
    //Feature Post
    if($post_type == 'post'){
      if ( isset($_POST['twinkle_feature_post'])){
        $twinkle_featured_post_meta = sanitize_text_field( wp_unslash($_POST['twinkle_feature_post']));
      }
      if ( isset( $twinkle_featured_post_meta ) ) {
        update_post_meta( $post_id, 'twinkle_feature_post', $twinkle_featured_post_meta );
      } else {
        delete_post_meta( $post_id, 'twinkle_feature_post' );
      }
    }
      
    //Post Style
    if ( isset($_POST['twinkle_current_post_style'])){
      $twinkle_post_style_meta = sanitize_text_field( wp_unslash($_POST['twinkle_current_post_style']));
    }
    if( isset( $twinkle_post_style_meta ) ){
      update_post_meta( $post_id, 'twinkle_post_style', $twinkle_post_style_meta );
    }else{
      delete_post_meta( $post_id, 'twinkle_post_style' );
    }
    
    //Featured Video
    if ( isset($_POST['twinkle_featuredvideo'])){
      $twinkle_featuredvideo_meta = esc_url_raw( wp_unslash($_POST['twinkle_featuredvideo']));
    }
    if ( isset( $twinkle_featuredvideo_meta ) ) {
      update_post_meta( $post_id, 'twinkle_featured_video', $twinkle_featuredvideo_meta );
    } else {
      delete_post_meta( $post_id, 'twinkle_featured_video' );
    }

    //Custom Imagecover for Video
    if ( isset($_POST['twinkle_imagecover'])){
      $twinkle_featuredvideo_imagecover_meta = sanitize_text_field( wp_unslash( $_POST['twinkle_imagecover']));
    }
    if ( isset( $twinkle_featuredvideo_imagecover_meta ) ) {
      update_post_meta( $post_id, 'twinkle_image_as_videocover', $twinkle_featuredvideo_imagecover_meta );
    } else {
      delete_post_meta( $post_id, 'twinkle_image_as_videocover' );
    }

  }

add_action( 'save_post', 'twinkle_save_meta_box_data' );


function twinkle_page_settings_custom_meta_boxes( $post ) {
    add_meta_box( 
        'twinkle-page-settings',
        __( 'Page Settings', 'twinkle' ),
        'twinkle_page_settings_meta_box',
        'page',
        'normal',
        'high'
    );
}
add_action( 'add_meta_boxes_page', 'twinkle_page_settings_custom_meta_boxes' );

/**
 * Build custom field meta box
 *
 * @param post $post The post object
 */
function twinkle_page_settings_meta_box( $post ){

  // make sure the form request comes from WordPress
  wp_nonce_field( basename( __FILE__ ), 'twinkle_meta_box_nonce' );

  $twinkle_current_post_style     = ( '' !== ( get_post_meta( $post->ID, 'twinkle_post_style', true ) ) )            ? get_post_meta( $post->ID, 'twinkle_post_style', true )          : 'Style 1';
  $twinkle_current_featured_video = ( NULL !== ( get_post_meta( $post->ID, 'twinkle_featured_video', true ) ) )      ? get_post_meta( $post->ID, 'twinkle_featured_video', true )      : '';
  $twinkle_current_image_as_cover = ( '' !== ( get_post_meta( $post->ID, 'twinkle_image_as_videocover', true ) ) )   ? get_post_meta( $post->ID, 'twinkle_image_as_videocover', true ) : '0';

  ?>

  <div class='inside'>

    <h3 style="border-bottom: 1px solid #dedede;padding-bottom: 10px;margin-top: 30px;"><?php esc_html_e( 'Page Style', 'twinkle' ); ?></h3>
    <p>
      <input type="radio" name="twinkle_current_post_style" value="Style 1" <?php checked( $twinkle_current_post_style, 'Style 1' ); ?> /><?php esc_html_e('Style 1', 'twinkle'); ?><br />
      <input type="radio" name="twinkle_current_post_style" value="Style 2" <?php checked( $twinkle_current_post_style, 'Style 2' ); ?> /><?php esc_html_e('Style 2', 'twinkle'); ?><br />
      <input type="radio" name="twinkle_current_post_style" value="Style 3" <?php checked( $twinkle_current_post_style, 'Style 3' ); ?> /><?php esc_html_e('Style 3', 'twinkle'); ?><br />
    </p>
    <h3 style="border-bottom: 1px solid #dedede;padding-bottom: 10px;margin-top: 30px;"><?php esc_html_e( 'Featured Video?', 'twinkle' ); ?></h3>
    <p><?php esc_html_e( 'If you want to use a Video enter the url (Youtube / Vimeo) in the field below', 'twinkle' ); ?></p>
    <p>
      <label><?php esc_html_e('Video URL:', 'twinkle'); ?></label>
      <input type="text" name="twinkle_featuredvideo" size="50" value="<?php echo esc_url($twinkle_current_featured_video); ?>" /> 
    </p> 
    <h3 style="border-bottom: 1px solid #dedede;padding-bottom: 10px;margin-top: 30px;"><?php esc_html_e( 'Use Featured Image as Video Cover?', 'twinkle' ); ?></h3>
    <p>
      <input type="radio" name="twinkle_imagecover" value="0" <?php checked( $twinkle_current_image_as_cover, '0' ); ?> /><?php esc_html_e('No', 'twinkle'); ?><br />
      <input type="radio" name="twinkle_imagecover" value="1" <?php checked( $twinkle_current_image_as_cover, '1' ); ?> /><?php esc_html_e('Yes', 'twinkle'); ?>
    </p>
    
  </div>
  <?php
}