<?php
/**
 * Declaring widgets
 *
 *
 * @package twinkle
 */
function twinkle_widgets_init() {

	register_sidebar( array(
		'name'          => __( 'Sidebar', 'twinkle' ),
		'id'            => 'sidebar-1',
		'description'   =>  __('Sidebar widget area', 'twinkle'),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

  register_sidebar( array(
      'name'          => __( 'Footer Column 1', 'twinkle' ),
      'id'            => 'footer-col-1',
      'description'   =>  __('Widget area column 1', 'twinkle' ),
      'before_widget' => '',
      'after_widget'  => '',
      'before_title'  => '<h3 class="widget-title">',
	    'after_title'   => '</h3>',
  ) );

  register_sidebar( array(
      'name'          => __( 'Footer Column 2', 'twinkle' ),
      'id'            => 'footer-col-2',
      'description'   =>  __('Widget area column 2', 'twinkle' ),
      'before_widget' => '',
      'after_widget'  => '',
      'before_title'  => '<h3 class="widget-title">',
	    'after_title'   => '</h3>',
  ) );

  register_sidebar( array(
      'name'          => __( 'Footer Column 3', 'twinkle' ),
      'id'            => 'footer-col-3',
      'description'   =>  __('Widget area column 3', 'twinkle' ),
      'before_widget' => '',
      'after_widget'  => '',
      'before_title'  => '<h3 class="widget-title">',
	    'after_title'   => '</h3>',
  ) );

  register_sidebar( array(
      'name'          => __( 'Footer Column 4', 'twinkle' ),
      'id'            => 'footer-col-4',
      'description'   =>  __('Widget area column 4', 'twinkle' ),
      'before_widget' => '',
      'after_widget'  => '',
      'before_title'  => '<h3 class="widget-title">',
	    'after_title'   => '</h3>',
  ) );

}
add_action( 'widgets_init', 'twinkle_widgets_init' );



/**
  * twinkle Latest Posts Class
  */

class Twinkle_Latest_Posts extends WP_Widget {

  /**
    * Register widget with WordPress.
    */

  public function __construct() {
    parent::__construct(
      'twinkle_latest_posts', // Base ID
      __( 'twinkle Theme: Latest Posts', 'twinkle' ), // Name
      array( 'description' => __( 'Custom latest posts', 'twinkle' ), ) // Args
    );
  }

  /**
    * Front-end display of widget.
    *
    * @see WP_Widget::widget()
    *
    * @param array $args     Widget arguments.
    * @param array $instance Saved values from database.
    */
  public function widget( $args, $instance ) {

    extract( $args );

    $title = apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base );

    echo $args['before_widget'];

    if ( ! empty( $instance['title'] ) ) {
      echo $args['before_title'] . esc_html($title) . $args['after_title'];
    }
    if(isset( $instance['posts_number'] )) {
      $posts_number = absint( $instance['posts_number'] );
    } else {
      $posts_number = 3;
    }
    if(isset( $instance['categories'] )) {
      $categories = esc_html( $instance['categories'] );
    } else {
      $categories = 'ALL';
    }


    /** Latest Posts Query */
    global $post;
    if($categories == 'ALL'){
      $twinkle_latest_posts = new WP_Query(
        array(
          'post_type' => 'post',
          'posts_per_page' => $posts_number,
          'post__not_in' => array( $post->ID ),
          'ignore_sticky_posts' => 1
        )
      );
    }
    else {
      $twinkle_latest_posts = new WP_Query(
        array(
          'post_type' => 'post',
          'posts_per_page' => $posts_number,
          'post__not_in' => array( $post->ID ),
          'category__in' => $categories,
          'ignore_sticky_posts' => 1
        )
      );
    }

    if ( $twinkle_latest_posts->have_posts() ): ?>
      <div class="twinkle_latest_posts">
        <ul class="clearfix">
          <?php while ( $twinkle_latest_posts->have_posts() ) : $twinkle_latest_posts->the_post(); ?>
            <li>
              <a class="twinkle_latest_posts_link" href="<?php the_permalink(); ?>">
                <figure class="entry-image">
                  <?php if ( has_post_thumbnail() ) { ?>
                    <?php the_post_thumbnail( 'twinkle-latest-posts-widget' ); ?>
                  <?php } else {
                    echo '<div class="noimage-placeholder"></div>';
                  } ?>
                  <span class="post-type-icon <?php echo esc_html(get_post_format()); ?>"></span>
                </figure>

                <h5 class="widget-post-title"><?php the_title(); ?></h5>
                <?php echo '<div class="widget-post-date">' . get_the_date(get_option('date_format')) . '</div>'; ?>
              </a>
            </li>
          <?php endwhile; ?>
        </ul>
      </div>

      <?php echo $args['after_widget'];
      wp_reset_postdata();

    endif;

  }





  /**
    * Back-end widget form.
    *
    * @see WP_Widget::form()
    *
    * @param array $instance Previously saved values from database.
    */
  public function form( $instance ) {

    /* Default widget settings. */
    $defaults = array(
      'title' => 'Latest Posts',
      'posts_number' => 3,
      'categories' => __('ALL', 'twinkle')
    );
    $instance = wp_parse_args( $instance, $defaults );

    ?>
    <p>
      <label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e('Title:', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($instance['title']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_id( 'posts_number' )); ?>"><?php esc_html_e('Number of posts to show:', 'twinkle'); ?></label>
      <input class="tiny-text" id="<?php echo esc_attr($this->get_field_id( 'posts_number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'posts_number' )); ?>" type="number" step="1" min="1" value="<?php echo absint($instance['posts_number']); ?>" size="3" /></p>
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_id('categories')); ?>"><?php esc_html_e( 'Post Category', 'twinkle' ); ?></label>
      <select id="<?php echo esc_attr($this->get_field_id('categories')); ?>" name="<?php echo esc_attr($this->get_field_name('categories')); ?>" class="widefat" style="width:100%;">
        <option>ALL</option>
        <?php foreach(get_terms('category','parent=0&hide_empty=0') as $term) { ?>
          <option <?php selected( $instance['categories'], $term->term_id ); ?> value="<?php echo esc_attr($term->term_id); ?>"><?php echo esc_html($term->name); ?></option>
        <?php } ?>
      </select>
    </p>
    <?php
  }


  /**
    * Sanitize widget form values as they are saved.
    *
    * @see WP_Widget::update()
    *
    * @param array $new_instance Values just sent to be saved.
    * @param array $old_instance Previously saved values from database.
    *
    * @return array Updated safe values to be saved.
    */
  public function update( $new_instance, $old_instance ) {

    $instance = array();

    $instance['title']        = ( ! empty( $new_instance['title'] ) )         ? sanitize_text_field( $new_instance['title'] )         : '';
    $instance['posts_number'] = ( ! empty( $new_instance['posts_number'] ) )  ? absint( $new_instance['posts_number'] )               : 3;
    $instance['categories']   = ( ! empty( $new_instance['categories'] ) )    ? sanitize_text_field( $new_instance['categories'] )    : __('ALL', 'twinkle');

    return $instance;

  }

}

function twinkle_custom_latest_posts() {
    register_widget( 'Twinkle_Latest_Posts' );
}
add_action( 'widgets_init', 'twinkle_custom_latest_posts' );



/**
 * twinkle About Auhtor Widget Class
 */

class Twinkle_About_Author extends WP_Widget {


  /**
   * Register widget with WordPress.
   */

  public function __construct() {
    parent::__construct(
      'twinkle_about_author', // Base ID
      __( 'twinkle Theme: About the Author', 'twinkle' ), // Name
      array( 'description' => __( 'About the author information', 'twinkle' ), ) // Args
    );
  }

  /**
    * Front-end display of widget.
    *
    * @see WP_Widget::widget()
    *
    * @param array $args     Widget arguments.
    * @param array $instance Saved values from database.
    */

  public function widget( $args, $instance ) {

    extract( $args );

    $title = apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base );

    echo $args['before_widget'];

    if ( ! empty( $instance['title'] ) ) {
      echo $args['before_title'] . esc_html($title) . $args['after_title'];
    } 
    ?>

    <div class="twinkle_about_author">
      <?php if ( ! empty( $instance['about_image'] ) ) { ?>
        <figure class="about-image">
          <img src="<?php echo esc_url($instance['about_image']); ?>">
        </figure>
      <?php } ?>

      <?php if ( ! empty( $instance['about_name'] ) ) { ?>
        <h4 class="about-name">
          <?php echo esc_html($instance['about_name']); ?>
        </h4>
      <?php } ?>

      <?php if ( ! empty( $instance['about_content'] ) ) { ?>
        <p class="about-content">
          <?php echo esc_html($instance['about_content']); ?>
        </p>
      <?php } ?>


      <div class="about-author-social-wrapper">
        <?php if ( ! empty( $instance['facebook'] ) ) { ?>
          <a href="<?php echo esc_url($instance['facebook']); ?>" target="_blank" class="about-author-social facebook"></a>
        <?php } ?>
        <?php if ( ! empty( $instance['twitter'] ) ) { ?>
          <a href="<?php echo esc_url($instance['twitter']); ?>" target="_blank" class="about-author-social twitter"></a>
        <?php } ?>
        <?php if ( ! empty( $instance['google+'] ) ) { ?>
          <a href="<?php echo esc_url($instance['google+']); ?>" target="_blank" class="about-author-social googleplus"></a>
        <?php } ?>
        <?php if ( ! empty( $instance['pinterest'] ) ) { ?>
          <a href="<?php echo esc_url($instance['pinterest']); ?>" target="_blank" class="about-author-social pinterest"></a>
        <?php } ?>
        <?php if ( ! empty( $instance['linkedin'] ) ) { ?>
          <a href="<?php echo esc_url($instance['linkedin']); ?>" target="_blank" class="about-author-social linkedin"></a>
        <?php } ?>
        <?php if ( ! empty( $instance['instagram'] ) ) { ?>
          <a href="<?php echo esc_url($instance['instagram']); ?>" target="_blank" class="about-author-social instagram"></a>
        <?php } ?>
        <?php if ( ! empty( $instance['dribbble'] ) ) { ?>
          <a href="<?php echo esc_url($instance['dribbble']); ?>" target="_blank" class="about-author-social dribbble"></a>
        <?php } ?>
      </div>


    </div>

    <?php echo $args['after_widget'];
  }





  /**
    * Back-end widget form.
    *
    * @see WP_Widget::form()
    *
    * @param array $instance Previously saved values from database.
    */
  public function form( $instance ) {

    /* Default widget settings. */
    $defaults = array(
      'title'         => __('About', 'twinkle'),
      'about_image'   => '',
      'about_name'    => '',
      'about_content' => '',
      'facebook'      => '',
      'twitter'       => '',
      'google+'       => '',
      'pinterest'     => '',
      'linkedin'      => '',
      'instagram'     => '',
      'dribbble'      => ''
    );

    $instance = wp_parse_args( $instance, $defaults ); ?>

    <p>
      <label for="<?php echo esc_attr($this->get_field_name( 'title' )); ?>"><?php esc_html_e('Title:', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($instance['title']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_name( 'about_image' )); ?>"><?php esc_html_e( 'Image URL:', 'twinkle' ); ?></label>
      <input type="url" id="<?php echo esc_attr($this->get_field_id( 'about_image' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'about_image' )); ?>" value="<?php echo esc_url($instance['about_image']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_name( 'about_name' )); ?>"><?php esc_html_e('Name:', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id( 'about_name' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'about_name' )); ?>" value="<?php echo esc_attr($instance['about_name']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_name('about_content')); ?>"><?php esc_html_e('Description:', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id('about_content')); ?>" name="<?php echo esc_attr($this->get_field_name('about_content')); ?>" value="<?php echo esc_attr($instance['about_content']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_name( 'facebook' )); ?>"><?php esc_html_e('Facebook URL', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id( 'facebook' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'facebook' )); ?>" value="<?php echo esc_url($instance['facebook']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_name( 'twitter' )); ?>"><?php esc_html_e('Twitter URL', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id( 'twitter' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'twitter' )); ?>" value="<?php echo esc_url($instance['twitter']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_name( 'google+' )); ?>"><?php esc_html_e('Google+ URL', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id( 'google+' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'google+' )); ?>" value="<?php echo esc_url($instance['google+']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_name( 'pinterest' )); ?>"><?php esc_html_e('Pinterest URL', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id( 'pinterest' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'pinterest' )); ?>" value="<?php echo esc_url($instance['pinterest']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_name( 'linkedin' )); ?>"><?php esc_html_e('LinkedIn URL', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id( 'linkedin' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'linkedin' )); ?>" value="<?php echo esc_url($instance['linkedin']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_name( 'instagram' )); ?>"><?php esc_html_e('Instagram URL', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id( 'instagram' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'instagram' )); ?>" value="<?php echo esc_url($instance['instagram']); ?>" class="widefat" />
    </p>
    <p>
      <label for="<?php echo esc_attr($this->get_field_name( 'dribbble' )); ?>"><?php esc_html_e('Dribbble URL', 'twinkle'); ?></label>
      <input type="text" id="<?php echo esc_attr($this->get_field_id( 'dribbble' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'dribbble' )); ?>" value="<?php echo esc_url($instance['dribbble']); ?>" class="widefat" />
    </p>

    <?php 
  }


  /**
    * Sanitize widget form values as they are saved.
    *
    * @see WP_Widget::update()
    *
    * @param array $new_instance Values just sent to be saved.
    * @param array $old_instance Previously saved values from database.
    *
    * @return array Updated safe values to be saved.
    */
  public function update( $new_instance, $old_instance ) {

    $instance = array();

    $instance['title']          = ( ! empty( $new_instance['title'] ) )         ? sanitize_text_field( $new_instance['title'] )          : '';
    $instance['about_image']    = ( ! empty( $new_instance['about_image'] ) )   ? esc_url_raw( $new_instance['about_image'] )            : '';
    $instance['about_name']     = ( ! empty( $new_instance['about_name'] ) )    ? sanitize_text_field( $new_instance['about_name'] )     : '';
    $instance['about_content']  = ( ! empty( $new_instance['about_content'] ) ) ? sanitize_text_field( $new_instance['about_content'] )  : '';
    $instance['facebook']       = ( ! empty( $new_instance['facebook'] ) )      ? esc_url_raw( $new_instance['facebook'] )               : '';
    $instance['twitter']        = ( ! empty( $new_instance['twitter'] ) )       ? esc_url_raw( $new_instance['twitter'] )                : '';
    $instance['google+']        = ( ! empty( $new_instance['google'] ) )        ? esc_url_raw( $new_instance['google+'] )                : '';
    $instance['pinterest']      = ( ! empty( $new_instance['pinterest'] ) )     ? esc_url_raw( $new_instance['pinterest'] )              : '';
    $instance['linkedin']       = ( ! empty( $new_instance['linkedin'] ) )      ? esc_url_raw( $new_instance['linkedin'] )               : '';
    $instance['instagram']      = ( ! empty( $new_instance['instagram'] ) )     ? esc_url_raw( $new_instance['instagram'] )              : '';
    $instance['dribbble']       = ( ! empty( $new_instance['dribbble'] ) )      ? esc_url_raw( $new_instance['dribbble'] )               : '';

    return $instance;
  }

}

function twinkle_about_author() {
    register_widget( 'Twinkle_About_Author' );
}
add_action( 'widgets_init', 'twinkle_about_author' );



